@@ -1,10 +1,10 @@
-__version__ = "0.1.4"
+__version__ = "0.1.5"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.1.4)'
+__git_branch__ = '(detached from v0.1.5)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'f9327d211c75ad37f88ab77382e323a5b9aa47ec'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '4dab8ed3f5c54991170c8fc92b997b549f80709b'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
